@@ -1,8 +1,13 @@
+
 /**
  * @file defFind.c
  *
  *  This module locates definitions.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
  *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
  *
@@ -55,7 +60,7 @@ static size_t
 bad_def_name(char * pzD, char const * pzS, size_t srcLen);
 
 static def_ent_t *
-find_def(char * name, def_ctx_t * pDefCtx, bool * indexed);
+find_def(char * name, def_ctx_t * def_ctx, bool * indexed);
 
 static int
 hash_string(unsigned char const * pz);
@@ -64,7 +69,7 @@ static void
 add_string(char const * pz);
 
 static def_ent_t **
-get_def_list(char * name, def_ctx_t * pDefCtx);
+get_def_list(char * name, def_ctx_t * def_ctx);
 /* = = = END-STATIC-FORWARD = = = */
 
 /**
@@ -419,11 +424,11 @@ canonical_name(char * pzD, char const * pzS, int srcLen)
  *  caller will not try to traverse the list of twins).
  *
  * @param[in]  name      name to look for
- * @param[in]  pDefCtx   definition context
+ * @param[in]  def_ctx   definition context
  * @param[out] indexed   whether the name was indexed or not
  */
 static def_ent_t *
-find_def(char * name, def_ctx_t * pDefCtx, bool * indexed)
+find_def(char * name, def_ctx_t * def_ctx, bool * indexed)
 {
     static int   nestingDepth = 0;
 
@@ -464,7 +469,7 @@ find_def(char * name, def_ctx_t * pDefCtx, bool * indexed)
          *  IF we are at the end of the definitions (reached ROOT),
          *  THEN it is time to bail out.
          */
-        ent = pDefCtx->dcx_defent;
+        ent = def_ctx->dcx_defent;
         if (ent == NULL)
             return NULL;
 
@@ -473,7 +478,7 @@ find_def(char * name, def_ctx_t * pDefCtx, bool * indexed)
              *  IF the name matches
              *  THEN break out of the double loop
              */
-            if (strcmp(ent->de_name, name) == 0)
+            if (streqvcmp(ent->de_name, name) == 0)
                 goto found_def_entry;
 
             ent = ent->de_next;
@@ -489,8 +494,8 @@ find_def(char * name, def_ctx_t * pDefCtx, bool * indexed)
         /*
          *  Let's go try the definitions at the next higher level.
          */
-        pDefCtx = pDefCtx->dcx_prev;
-        if (pDefCtx == NULL)
+        def_ctx = def_ctx->dcx_prev;
+        if (def_ctx == NULL)
             return NULL;
     } found_def_entry:;
 
@@ -744,7 +749,7 @@ print_used_defines(void)
  *  not try to traverse the list of twins).
  */
 static def_ent_t **
-get_def_list(char * name, def_ctx_t * pDefCtx)
+get_def_list(char * name, def_ctx_t * def_ctx)
 {
     static def_ent_list_t defList = { 0, 0, NULL, 0 };
 
@@ -785,7 +790,7 @@ get_def_list(char * name, def_ctx_t * pDefCtx)
          *  IF we are at the end of the definitions (reached ROOT),
          *  THEN it is time to bail out.
          */
-        ent = pDefCtx->dcx_defent;
+        ent = def_ctx->dcx_defent;
         if (ent == NULL) {
             /*
              *  Make sure we are not nested.  Once we start to nest,
@@ -822,8 +827,8 @@ get_def_list(char * name, def_ctx_t * pDefCtx)
         /*
          *  Let's go try the definitions at the next higher level.
          */
-        pDefCtx = pDefCtx->dcx_prev;
-        if (pDefCtx == NULL)
+        def_ctx = def_ctx->dcx_prev;
+        if (def_ctx == NULL)
             goto not_found;
     } found_def_entry:;
 
@@ -933,7 +938,9 @@ find_def_ent_list(char * name)
 {
     return get_def_list(name, &curr_def_ctx);
 }
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
