@@ -14,11 +14,11 @@
 ##   The Modified Berkeley Software Distribution License
 ##      See the file "COPYING.mbsd"
 ##
-##  These files have the following md5sums:
+##  These files have the following sha256 sums:
 ##
-##  43b91e8ca915626ed3818ffb1b71248b pkg/libopts/COPYING.gplv3
-##  06a1a2e4760c90ea5e1dad8dfaac4d39 pkg/libopts/COPYING.lgplv3
-##  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
+##  8584710e9b04216a394078dc156b781d0b47e1729104d666658aecef8ee32e95  COPYING.gplv3
+##  4379e7444a0e2ce2b12dd6f5a52a27a4d02d39d247901d3285c88cf0d37f477b  COPYING.lgplv3
+##  13aa749a5b0a454917a944ed8fffc530b784f5ead522b1aacaf4ec8aa55a6239  COPYING.mbsd
 
 egrep '#undef +AUTOOPTS_ENABLED' ${top_builddir}/config.h >/dev/null && \
     exit 0
@@ -26,16 +26,14 @@ egrep '#undef +AUTOOPTS_ENABLED' ${top_builddir}/config.h >/dev/null && \
 srcdir=`dirname $0`
 srcdir=`cd ${srcdir} ; pwd`
 
-. ${top_builddir}/autoopts/test/defs
-
-test -z "${POSIX_SHELL}" && exit 1
+. ${top_builddir}/config/shdefs
 
 rm -f ${DESTdestdir}/options.h ${DESTdestdir}/usage-txt.h
 opthdrsrc=${srcdir}/autoopts/options.h
 usehdrsrc=${srcdir}/autoopts/usage-txt.h
 cfgf=${top_builddir}/config.h
 
-{
+emit_options_h() {
     sed '/^#include <stdio/q' ${opthdrsrc}
 
     if ${EGREP} 'define +HAVE_STDINT_H' ${cfgf} >/dev/null
@@ -86,9 +84,10 @@ cfgf=${top_builddir}/config.h
     else nopathfind='/HAVE_PATHFIND/d' ; fi
 
     sed "${sedcmd};${nopathfind}" ${opthdrsrc}
-} > ${DESTdestdir}/options.h
+}
+emit_options_h > ${DESTdestdir}/options.h
 
-sed '/#if.*AUTOOPTS_INTERNAL/,/#endif.*XGETTEXT_SCAN/d' \
+sed '/#if.*AUTOOPTS_INTERNAL/,/#endif.*AUTOOPTS_INTERNAL/d' \
   ${usehdrsrc} > ${DESTdestdir}/usage-txt.h
 
 test -d "${DESTpkgdatadir}" && {
@@ -99,8 +98,8 @@ test -d "${DESTpkgdatadir}" && {
     cd ${DESTpkgdatadir}
     for f in *
     do  case "$f" in
-        optlib.tlib    | getopt.tpl | usage.tlib | cmd-doc.tlib | \
-        agtexi-cmd.tpl | agman1.tpl | aginfo.tpl )
+        agtexi-cmd.tpl | cmd-doc.tlib | def2pot.tpl   | \
+        getopt.tpl     | options.tpl  | str2init.tlib | usage.tlib)
             sed "${rmbuild}" $f > $f.tmp
             mv -f $f.tmp $f
             ;;
