@@ -84,7 +84,7 @@ do_enum() {
         .El* )           echo '.in -4'
                          return 0          ;;
 
-        * )              echo "$line"      ;;
+        * )              printf '%s\n' "$line" ;;
         esac
     done
     die "EOF reached processing '.Bl -enum'"
@@ -95,8 +95,7 @@ do_nest_tag() {
     while IFS='' read -r line
     do
         case "${line}" in
-        .It* ) printf '.ti -4\n.IR '
-               echo ${line#.It} ;;
+        .It* ) printf '.ti -4\n.IR%s\n' "${line#.It}" ;;
 
         .Bl' '*enum* )   do_nest_enum      ;;
         .Bl' '*tag* )    do_nest_tag       ;;
@@ -109,7 +108,7 @@ do_nest_tag() {
         .El* )           echo '.in -4'
                          return 0          ;;
 
-        * )              echo "$line"      ;;
+        * )              printf '%s\n' "$line" ;;
         esac
     done
     die "EOF reached processing '.Bl -tag'"
@@ -119,8 +118,7 @@ do_tag() {
     while IFS='' read -r line
     do
         case "${line}" in
-        .It* ) printf '.TP\n.BR '
-               echo ${line#.It}            ;;
+        .It* ) printf '.TP\n.BR%s\n' "${line#.It}" ;;
 
         .Bl' '*enum* )   do_nest_enum      ;;
         .Bl' '*tag* )    do_nest_tag       ;;
@@ -130,7 +128,7 @@ do_tag() {
         .Fl' '* )        do_nest_flag      ;;
         .Ar' '* )        do_nest_arg       ;;
         .El* )           return 0          ;;
-        * )              echo "$line"      ;;
+        * )              printf '%s\n' "$line" ;;
         esac
     done
     die "EOF reached processing '.Bl -tag'"
@@ -145,8 +143,7 @@ do_bullet() {
     while IFS='' read -r line
     do
         case "${line}" in
-        .It* ) printf '.ti -4\n\\fB*\\fP\n'
-               echo ${line#.It}
+        .It* ) printf '.ti -4\n\\fB*\\fP\n%s\n' "${line#.It}"
                ;;
 
         .Bl' '*enum* )   do_nest_enum      ;;
@@ -160,7 +157,7 @@ do_bullet() {
         .El* )           echo '.in -4'
                          return 0          ;;
 
-        * )              echo "$line"      ;;
+        * )              printf '%s\n' "$line" ;;
         esac
     done
     die "EOF reached processing '.Bl -bullet'"
@@ -181,7 +178,7 @@ do_block() {
                echo .fi
                return 0          ;;
 
-        * )    echo "$line"      ;;
+        * )    printf '%s\n' "$line" ;;
         esac
     done
     die "EOF reached processing '.Bd'"
@@ -238,7 +235,7 @@ do_nest_flag() {
 }
 
 do_flag() {
-    echo ${line#.Fl}
+    printf '%s\n' "${line#.Fl}"
 }
 
 do_nest_arg() {
@@ -247,12 +244,12 @@ do_nest_arg() {
 
 do_arg() {
     line=`echo ${line#.Ar}`
-    echo "\\fI${line}\\fR"
+    printf "\\fI${line}\\fR\n"
 }
 
 do_NmName() {
     # do we want to downcase the line first?  Yes...
-    set -- `echo ${line#.Nm} | \
+    set -- `printf '%s\n' "${line#.Nm}" | \
         sed -e 's/-/\\-/g' \
             -e 'y/ABCDEFGHIJKLMNOPQRSTUVWXYZ/abcdefghijklmnopqrstuvwxyz/'`
     NmNameSfx=
@@ -281,7 +278,7 @@ do_line() {
     .Ar' '* )        do_arg       ;;
     .Nm' '* )        do_NmName    ;;
     .Nm     )        do_NmName    ;;
-    * )              echo "$line" ;;
+    * )              printf '%s\n' "$line" ;;
     esac
     return 0
 }
