@@ -17,20 +17,25 @@
 ##  You should have received a copy of the GNU General Public License along
 ##  with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-d=`dirname $0`
-d=`cd $d ; pwd`
-prog=${d}/`basename $0`
-parent_pid=$$
+typeset -r prog=$(basename "$0" .sh)
+typeset -r progdir=$(\cd $(dirname "$0") && pwd -P)
+typeset -r program=${progdir}/$(basename "$0")
+typeset -r progpid=$$
+
+builddir=`pwd`
+. ${top_builddir:-..}/config/shdefs
 
 die()
 {
-  exec 2>&8 1>&2 8>&-
+  exec 1> ${TMPDIR}/err-report.txt 2>&1
   echo "mk-agen-texi FAILED: $*"
   echo
   cat ${LOG_FILE}
+  exec 2>&8 1>&2 8>&-
+  cat ${TMPDIR}/err-report.txt
   trap : EXIT
   echo leaving ${TMPDIR} in place
-  kill -TERM ${parent_pid}
+  kill -TERM ${progpid}
   exit 1
 }
 
@@ -55,9 +60,8 @@ set_config_values()
   nl='
 ' ht='	'
   . ${top_builddir}/config/shdefs
-
-  test -z "${MAKE}"   && MAKE=`which make`
-
+  : ${MAKE=`which make`}
+  : ${srcdir=`pwd`}
   srcdir=`cd ${srcdir} >/dev/null ; pwd`
   INCLUDES="${DEFS} "`
 
@@ -191,9 +195,6 @@ sanity_check()
   do test -f ${f} || die cannot find doc file: ${f}
      test -f `basename $f` || ln -s $f .
   done
-
-  cmd=${AGexe}
-  ${VERBOSE} && cmd=${cmd}" --trace=every --trace-out=>>${TMPDIR}/ag.log"
 }
 
 build_agdoc() {
@@ -204,9 +205,9 @@ build_agdoc() {
   sanity_check
   run_getdefs
 
-  VERBOSE=true
-
-  env >&2
+  {
+    sh -c set | sed '/^BASH/d'
+  } >&2
   {
     cat <<- _EOF_
 	timeout     ${timer}
@@ -216,18 +217,19 @@ build_agdoc() {
 	make-dep    F ${GEN_BASE}.dep
 	make-dep    P
 	_EOF_
-    ${VERBOSE} && false && {
+    ${VERBOSE} && {
       echo 'trace       every'
       echo "trace-out   >>${TMPDIR}/ag.log"
+      export VERBOSE
     }
   } > ${TMPDIR}/ag.ini
 
   opts="--load-opts=${TMPDIR}/ag.ini"
-  cmd=`echo "${cmd}" ${opts} ${TMPDIR}/${GEN_BASE}.def`
+  cmd=`echo ${AGexe} ${opts} ${TMPDIR}/${GEN_BASE}.def`
   echo "${PS4:-+} " ${cmd} >&8
 
-  ${cmd} || {
-    cat ${TMPDIR}/ag.ini ${TMPDIR}/ag.log
+  timeout ${timer}s ${cmd} || {
+    head -n999999 ${TMPDIR}/ag.ini ${TMPDIR}/*.log
     die could not regenerate doc
   } >&2
 
